@@ -256,14 +256,17 @@ def GetReservationNameFlag():
 def GetDeploymentTypeFlag():
   """--deployment-type flag."""
   help_text = """\
-  Indicates if the reservation allocation strategy is static or dynamic. DENSE
-  refers to a fixed size and topology, with deployment expressed in terms of
-  blocks. FLEXIBLE indicates a non-static distribution of capacity that can
-  change over time. Deployment is not expressed in blocks.
+  The deployment type for the reserved capacity.
   """
   return base.Argument(
       '--deployment-type',
-      choices=['DENSE', 'FLEXIBLE'],
+      choices={
+          'DENSE': 'DENSE mode is for densely deployed reservation blocks.',
+          'FLEXIBLE': (
+              'FLEXIBLE mode is for highly flexible, logical reservation'
+              ' blocks.'
+          ),
+      },
       help=help_text,
   )
 
@@ -297,28 +300,23 @@ def GetPreviousCommitmentTermsHelpText():
   return help_text
 
 
-def GetInstanceTerminationActionFlag():
-  """--instance-termination-action flag."""
-  help_text = """\
-  Specific termination action for running instances at the end of reservation
-  duration, it can be DELETE or STOP.
-  """
-  return base.Argument(
-      '--instance-termination-action',
-      choices=['DELETE', 'STOP'],
-      help=help_text,
-  )
-
-
 def GetSchedulingTypeFlag():
   """--scheduling-type flag."""
   help_text = """\
-  Indicates the maintenance type for this group of VMs. This will be set on the
-  reservation via FR, and will be inherited for reservation blocks.
+  Maintenance for the reserved capacity.
   """
   return base.Argument(
       '--scheduling-type',
-      choices=['GROUPED', 'INDEPENDENT'],
+      choices={
+          'GROUPED': (
+              'In GROUPED mode, maintenance on all reserved instances is'
+              'synchronized.'
+          ),
+          'INDEPENDENT': (
+              'In INDEPENDENT mode, maintenance is not synchronized for this'
+              ' reservation, and each instance has its own maintenance window.'
+          ),
+      },
       help=help_text,
   )
 
@@ -326,12 +324,12 @@ def GetSchedulingTypeFlag():
 def GetEnableOpportunisticMaintenanceFlag():
   """--enable-opportunistic-maintenance flag."""
   help_text = """\
-  Indicates if this group of VMs have opportunistic maintenance enabled.
-  Applicable only to dense coordinated maintenance.
+  Enable or disable opportunistic maintenance. If enabled, maintenance is
+  performed on unused reservations whenever possible.
   """
   return base.Argument(
       '--enable-opportunistic-maintenance',
-      type=bool,
+      action=arg_parsers.StoreTrueFalseAction,
       help=help_text,
   )
 
@@ -412,7 +410,6 @@ def AddCreateFlags(
     GetReservationNameFlag().AddToParser(parser)
     GetDeploymentTypeFlag().AddToParser(parser)
     AddCommitmentInfoFlags(parser)
-    GetInstanceTerminationActionFlag().AddToParser(parser)
     GetSchedulingTypeFlag().AddToParser(parser)
     GetEnableOpportunisticMaintenanceFlag().AddToParser(parser)
 
@@ -505,7 +502,6 @@ def AddUpdateFlags(
     GetReservationNameFlag().AddToParser(parser)
     GetDeploymentTypeFlag().AddToParser(parser)
     AddCommitmentInfoFlags(parser)
-    GetInstanceTerminationActionFlag().AddToParser(parser)
     GetSchedulingTypeFlag().AddToParser(parser)
     GetEnableOpportunisticMaintenanceFlag().AddToParser(parser)
 
@@ -559,12 +555,16 @@ def AddCommitmentInfoFlags(parser):
       help='Manage the commitment info properties',
       required=False,
   )
-  commitment_info_group.add_argument('--commitment-name',
-                                     type=str, help=GetCommitmentNameHelpText())
-  commitment_info_group.add_argument('--commitment-plan',
-                                     choices=['TWELVE_MONTH',
-                                              'THIRTY_SIX_MONTH'],
-                                     help=GetCommitmentPlanHelpText())
-  commitment_info_group.add_argument('--previous-commitment-terms',
-                                     choices=['EXTEND'],
-                                     help=GetPreviousCommitmentTermsHelpText())
+  commitment_info_group.add_argument(
+      '--commitment-name', type=str, help=GetCommitmentNameHelpText()
+  )
+  commitment_info_group.add_argument(
+      '--commitment-plan',
+      choices=['TWELVE_MONTH', 'THIRTY_SIX_MONTH'],
+      help=GetCommitmentPlanHelpText(),
+  )
+  commitment_info_group.add_argument(
+      '--previous-commitment-terms',
+      choices=['EXTEND'],
+      help=GetPreviousCommitmentTermsHelpText(),
+  )
