@@ -60,8 +60,8 @@ class SupportedFeatures:
       support_max_count_per_zone,
       support_performance_monitoring_unit,
       support_custom_hostnames,
-      support_storage_pool,
       support_specific_then_x_affinity,
+      support_watchdog_timer,
   ):
     self.support_rsa_encrypted = support_rsa_encrypted
     self.support_secure_tags = support_secure_tags
@@ -95,8 +95,9 @@ class SupportedFeatures:
         support_performance_monitoring_unit
     )
     self.support_custom_hostnames = support_custom_hostnames
-    self.support_storage_pool = support_storage_pool
     self.support_specific_then_x_affinity = support_specific_then_x_affinity
+    self.support_watchdog_timer = support_watchdog_timer
+    self.support_replica_zones = True
 
 
 def _GetSourceInstanceTemplate(args, resources, instance_template_resource):
@@ -346,9 +347,11 @@ def CreateBulkInsertInstanceResource(args, holder, compute_client,
         compute_client=compute_client,
         resource_parser=resource_parser,
         image_uri=image_uri,
+        holder=holder,
         create_boot_disk=create_boot_disk,
         boot_disk_size_gb=boot_disk_size_gb,
         support_kms=True,
+        support_replica_zones=supported_features.support_replica_zones,
         support_nvdimm=supported_features.support_nvdimm,
         support_source_snapshot_csek=supported_features
         .support_source_snapshot_csek,
@@ -356,8 +359,7 @@ def CreateBulkInsertInstanceResource(args, holder, compute_client,
         support_image_csek=supported_features.support_image_csek,
         support_create_disk_snapshots=supported_features
         .support_create_disk_snapshots,
-        use_disk_type_uri=False,
-        support_storage_pool=supported_features.support_storage_pool)
+        use_disk_type_uri=False)
 
   machine_type_name = None
   if instance_utils.CheckSpecifiedMachineTypeArgs(args, skip_defaults):
@@ -387,6 +389,11 @@ def CreateBulkInsertInstanceResource(args, holder, compute_client,
           supported_features.support_performance_monitoring_unit
           and args.performance_monitoring_unit
       )
+      or (
+          supported_features.support_watchdog_timer
+          and args.enable_watchdog_timer is not None
+      )
+      or (args.turbo_mode is not None)
   ):
     visible_core_count = (
         args.visible_core_count
@@ -406,6 +413,10 @@ def CreateBulkInsertInstanceResource(args, holder, compute_client,
             args.performance_monitoring_unit
             if supported_features.support_performance_monitoring_unit
             else None,
+            args.enable_watchdog_timer
+            if supported_features.support_watchdog_timer
+            else None,
+            args.turbo_mode,
         )
     )
 
@@ -453,8 +464,9 @@ def CreateBulkInsertInstanceResource(args, holder, compute_client,
     instance_properties.secureTags = secure_tags_utils.GetSecureTags(
         args.secure_tags)
   if args.resource_manager_tags:
-    ret_resource_manager_tags = resource_manager_tags_utils.GetResourceManagerTags(
-        args.resource_manager_tags)
+    ret_resource_manager_tags = (
+        resource_manager_tags_utils.GetResourceManagerTags(
+            args.resource_manager_tags))
     if ret_resource_manager_tags is not None:
       properties_message = compute_client.messages.InstanceProperties
       instance_properties.resourceManagerTags = properties_message.ResourceManagerTagsValue(
@@ -467,15 +479,18 @@ def CreateBulkInsertInstanceResource(args, holder, compute_client,
   if supported_features.support_display_device and display_device:
     instance_properties.displayDevice = display_device
 
-  if supported_features.support_confidential_compute and confidential_instance_config:
-    instance_properties.confidentialInstanceConfig = confidential_instance_config
+  if (supported_features.support_confidential_compute and
+      confidential_instance_config):
+    instance_properties.confidentialInstanceConfig = (
+        confidential_instance_config)
 
   if supported_features.support_erase_vss and args.IsSpecified(
       'erase_windows_vss_signature'):
-    instance_properties.eraseWindowsVssSignature = args.erase_windows_vss_signature
+    instance_properties.eraseWindowsVssSignature = (
+        args.erase_windows_vss_signature)
 
-  if supported_features.support_post_key_revocation_action_type and args.IsSpecified(
-      'post_key_revocation_action_type'):
+  if (supported_features.support_post_key_revocation_action_type and
+      args.IsSpecified('post_key_revocation_action_type')):
     instance_properties.postKeyRevocationActionType = arg_utils.ChoiceToEnum(
         args.post_key_revocation_action_type, compute_client.messages.Instance
         .PostKeyRevocationActionTypeValueValuesEnum)
