@@ -217,13 +217,14 @@ class GceCredentialProvider(object):
   """Provides account, project and credential data for gce vm env."""
 
   def GetCredentials(self, account, use_google_auth=True):
-    if account in c_gce.Metadata().Accounts():
-      # Here we just return the google-auth credential without refreshing it.
-      # In _Load method we will attach the token store to the cred object, then
-      # refresh. This way the refreshed token can be cached in the token store
-      # automatically.
-      refresh = not use_google_auth
-      return AcquireFromGCE(account, use_google_auth, refresh)
+    if properties.VALUES.core.check_gce_metadata.GetBool():
+      if account in c_gce.Metadata().Accounts():
+        # Here we just return the google-auth credential without refreshing it.
+        # In _Load method we will attach the token store to the cred object,
+        # then refresh. This way the refreshed token can be cached in the
+        # token store automatically.
+        refresh = not use_google_auth
+        return AcquireFromGCE(account, use_google_auth, refresh)
     return None
 
   def GetAccount(self):
@@ -232,7 +233,9 @@ class GceCredentialProvider(object):
     return None
 
   def GetAccounts(self):
-    return set(c_gce.Metadata().Accounts())
+    if properties.VALUES.core.check_gce_metadata.GetBool():
+      return set(c_gce.Metadata().Accounts())
+    return set()
 
   def GetUniverseDomain(self):
     """Gets the universe domain from GCE metadata.
@@ -1837,8 +1840,9 @@ class _LegacyGenerator(object):
       self.scopes = scopes
 
     paths = config.Paths()
-    # Bq file is not generated here. bq CLI generates it using the adc at
-    # self._adc_path and uses it as the cache.
+    # Bq file is not generated here. When not using google auth (made the
+    # default in the gcloud 490 release) the bq CLI generates it using the adc
+    #  at self._adc_path and uses it as the cache.
     # Register so it is cleaned up.
     self._bq_path = paths.LegacyCredentialsBqPath(account)
     self._gsutil_path = paths.LegacyCredentialsGSUtilPath(account)
@@ -1877,6 +1881,7 @@ class _LegacyGenerator(object):
     """Write the credential file."""
 
     # Remove all the credential files first. As per the comment in __init__
+    # When not using google auth (made the default in the gcloud 490 release)
     # the BQ file (singlestore_bq) is created by the BQ CLI and not
     # regenerated. This file should be removed when the credentials are
     # created. If this file isn't removed, it will be stale, but BQ CLI will
