@@ -54,7 +54,10 @@ def _AddArgs(
     include_aggregate_purpose,
     include_l2,
     include_external_ipv6_prefix,
+    include_custom_hardware_link,
     api_version,
+    include_ip_collection,
+    include_peer_migration_purpose,
 ):
   """Add subnetwork create arguments to parser."""
   parser.display_info.AddFormat(flags.DEFAULT_LIST_FORMAT_WITH_IPV6_FIELD)
@@ -172,6 +175,16 @@ def _AddArgs(
         'private subnetworks.'
     )
 
+  if include_custom_hardware_link:
+    purpose_choices['CUSTOM_HARDWARE_LINK'] = (
+        'Reserved for Custom Hardware Link.'
+    )
+
+  if include_peer_migration_purpose:
+    purpose_choices['PEER_MIGRATION'] = (
+        'Reserved for subnet migration between peered VPCs.'
+    )
+
   # Subnetwork purpose is introduced with L7ILB feature. Aggregate purpose
   # will have to be enabled for a given release track only after L7ILB feature
   # is enabled for that release track. Hence if include_aggregate_purpose
@@ -208,13 +221,11 @@ def _AddArgs(
       'IPV4_IPV6': (
           'New VMs in this subnet can have both IPv4 and IPv6 addresses'
       ),
+      'IPV6_ONLY': (
+          'New VMs in this subnet will only be assigned IPv6 addresses'
+      )
   }
 
-  if api_version == compute_api.COMPUTE_ALPHA_API_VERSION:
-    stack_type_choices['IPV6_ONLY'] = (
-        'New VMs in this subnet will only be assigned IPv6 addresses'
-    )
-
   parser.add_argument(
       '--stack-type',
       choices=stack_type_choices,
@@ -299,6 +310,9 @@ def _AddArgs(
         For example, `--external-ipv6-prefix 2600:1901:0:0:0:0:0:0/64`
         """))
 
+  if include_ip_collection:
+    flags.IpCollectionArgument().AddArgument(parser)
+
 
 def GetPrivateIpv6GoogleAccessTypeFlagMapper(messages):
   return arg_utils.ChoiceEnumMapper(
@@ -325,6 +339,9 @@ def _CreateSubnetwork(
     include_aggregate_purpose,
     include_l2,
     include_external_ipv6_prefix,
+    include_custom_hardware_link,
+    ip_collection_ref,
+    include_peer_migration_purpose,
 ):
   """Create the subnet resource."""
   subnetwork = messages.Subnetwork(
@@ -391,11 +408,21 @@ def _CreateSubnetwork(
       == messages.Subnetwork.PurposeValueValuesEnum.GLOBAL_MANAGED_PROXY
       or subnetwork.purpose
       == messages.Subnetwork.PurposeValueValuesEnum.PRIVATE_SERVICE_CONNECT
+      or (
+          include_peer_migration_purpose
+          and subnetwork.purpose
+          == messages.Subnetwork.PurposeValueValuesEnum.PEER_MIGRATION
+      )
       or (
           include_aggregate_purpose
           and subnetwork.purpose
           == messages.Subnetwork.PurposeValueValuesEnum.AGGREGATE
       )
+      or (
+          include_custom_hardware_link
+          and subnetwork.purpose
+          == messages.Subnetwork.PurposeValueValuesEnum.CUSTOM_HARDWARE_LINK
+      )
   ):
     # Clear unsupported fields in the subnet resource
     subnetwork.privateIpGoogleAccess = None
@@ -430,6 +457,9 @@ def _CreateSubnetwork(
     if args.external_ipv6_prefix:
       subnetwork.externalIpv6Prefix = args.external_ipv6_prefix
 
+  if ip_collection_ref:
+    subnetwork.ipCollection = ip_collection_ref.SelfLink()
+
   return subnetwork
 
 
@@ -440,6 +470,9 @@ def _Run(
     include_aggregate_purpose,
     include_l2,
     include_external_ipv6_prefix,
+    include_custom_hardware_link,
+    include_ip_collection,
+    include_peer_migration_purpose,
 ):
   """Issues a list of requests necessary for adding a subnetwork."""
   client = holder.client
@@ -451,6 +484,10 @@ def _Run(
       args,
       holder.resources,
       scope_lister=compute_flags.GetDefaultScopeLister(client))
+  ip_collection_ref = None
+  if include_ip_collection and args.ip_collection:
+    ip_collection_ref = flags.IpCollectionArgument().ResolveAsResource(
+        args, holder.resources)
 
   subnetwork = _CreateSubnetwork(
       client.messages,
@@ -461,6 +498,9 @@ def _Run(
       include_aggregate_purpose,
       include_l2,
       include_external_ipv6_prefix,
+      include_custom_hardware_link,
+      ip_collection_ref,
+      include_peer_migration_purpose
   )
   request = client.messages.ComputeSubnetworksInsertRequest(
       subnetwork=subnetwork,
@@ -478,6 +518,7 @@ def _Run(
                                request)])
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class Create(base.CreateCommand):
   """Create a GA subnet."""
@@ -487,6 +528,9 @@ class Create(base.CreateCommand):
   _include_l2 = False
   _include_external_ipv6_prefix = False
   _api_version = compute_api.COMPUTE_GA_API_VERSION
+  _include_custom_hardware_link = False
+  _include_ip_collection = False
+  _include_peer_migration_purpose = False
 
   detailed_help = _DetailedHelp()
 
@@ -498,7 +542,10 @@ class Create(base.CreateCommand):
         cls._include_aggregate_purpose,
         cls._include_l2,
         cls._include_external_ipv6_prefix,
+        cls._include_custom_hardware_link,
         cls._api_version,
+        cls._include_ip_collection,
+        cls._include_peer_migration_purpose,
     )
 
   def Run(self, args):
@@ -511,6 +558,9 @@ class Create(base.CreateCommand):
         self._include_aggregate_purpose,
         self._include_l2,
         self._include_external_ipv6_prefix,
+        self._include_custom_hardware_link,
+        self._include_ip_collection,
+        self._include_peer_migration_purpose,
     )
 
 
@@ -519,6 +569,7 @@ class CreateBeta(Create):
   """Create a subnet in the Beta release track."""
 
   _api_version = compute_api.COMPUTE_BETA_API_VERSION
+  _include_ip_collection = False
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@@ -530,3 +581,6 @@ class CreateAlpha(CreateBeta):
   _include_l2 = True
   _include_external_ipv6_prefix = True
   _api_version = compute_api.COMPUTE_ALPHA_API_VERSION
+  _include_custom_hardware_link = True
+  _include_ip_collection = True
+  _include_peer_migration_purpose = True
