@@ -23,7 +23,7 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.iap import util as iap_util
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 @base.DefaultUniverseOnly
 class GetIamPolicy(base.ListCommand):
   """Get IAM policy for an IAP IAM resource.
@@ -109,6 +109,30 @@ class GetIamPolicy(base.ListCommand):
     return iap_iam_ref.GetIamPolicy()
 
 
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class GetIamPolicyBeta(GetIamPolicy):
+  """Get IAM policy for an IAP IAM resource.
+
+  *{command}* displays the IAM policy associated with an IAP IAM
+  resource. If formatted as JSON, the output can be edited and used as a policy
+  file for set-iam-policy. The output includes an "etag" field
+  identifying the version emitted and allowing detection of
+  concurrent policy updates; see
+  $ {parent_command} set-iam-policy for additional details.
+  """
+
+  @staticmethod
+  def Args(parser):
+    """Register flags for this command.
+
+    Args:
+      parser: An argparse.ArgumentParser-like object. It is mocked out in order
+          to capture some information, but behaves like an ArgumentParser.
+    """
+    iap_util.AddIapIamResourceArgs(parser, is_beta=True)
+    base.URI_FLAG.RemoveFromParser(parser)
+
+
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class GetIamPolicyAlpha(GetIamPolicy):
   """Get IAM policy for an IAP IAM resource.
@@ -129,5 +153,5 @@ class GetIamPolicyAlpha(GetIamPolicy):
       parser: An argparse.ArgumentParser-like object. It is mocked out in order
           to capture some information, but behaves like an ArgumentParser.
     """
-    iap_util.AddIapIamResourceArgs(parser, use_forwarding_rule=True)
+    iap_util.AddIapIamResourceArgs(parser, is_alpha=True)
     base.URI_FLAG.RemoveFromParser(parser)
